@@ -6,8 +6,7 @@ from typing import List
 class Library:
 
     def __init__(self, name: str, paths: List[str]):
-        assert(isinstance(name, str)), '`name` must be a string'
-        assert(isinstance(paths, list)), '`paths` must be a list'
+        """Create a Library object."""
         self.name = name
         self.paths = sum(
             [glob.glob(os.path.expanduser(p)) for p in paths],
@@ -17,6 +16,7 @@ class Library:
         return ":".join(self.paths)
 
     def __str__(self) -> str:
+        """Get the name of the library when formatting"""
         return self.name
 
 
